@@ -1,8 +1,7 @@
 /*
 **  OSSP cfg - Configuration Parsing
-**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2002-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
+**  Copyright (c) 2002-2006 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2006 The OSSP Project (http://www.ossp.org/)
 **
 **  This file is part of OSSP cfg, a configuration parsing
 **  library which can be found at http://www.ossp.org/pkg/lib/cfg/.
@@ -35,6 +34,9 @@
 #include "cfg_data.h"
 
 struct cfg_node_st {
+    /* attribute ownership */
+    unsigned long   owner;   /* attribute ownership bit field */
+
     /* node linkage */
     cfg_node_t     *parent;  /* pointer to parent node */
     cfg_node_t     *rbroth;  /* pointer to right brother node */
