@@ -1,8 +1,7 @@
 /*
 **  OSSP cfg - Configuration Parsing
-**  Copyright (c) 1999-2002 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 1999-2002 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2002 Cable & Wireless Deutschland (http://www.cw.com/de/)
+**  Copyright (c) 2002-2006 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2006 The OSSP Project (http://www.ossp.org/)
 **
 **  This file is part of OSSP cfg, a configuration parsing
 **  library which can be found at http://www.ossp.org/pkg/lib/cfg/.
@@ -35,8 +34,9 @@
 
 #include "cfg.h"
 #include "cfg_util.h"
+#include "cfg_global.h"
 
-cfg_rc_t cfg_util_readfile(const char *filename, char **buf_ptr, size_t *buf_len)
+cfg_rc_t cfg_util_readfile(const char *filename, char **buf_ptr, size_t *buf_size, size_t *buf_used)
 {
     FILE *fp = NULL;
     size_t n;
@@ -44,16 +44,16 @@ cfg_rc_t cfg_util_readfile(const char *filename, char **buf_ptr, size_t *buf_len
 
     if (strcmp(filename, "-") == 0) {
         /* file is given on stdin */
-        (*buf_len) = 32;
-        if ((*buf_ptr = (char *)malloc(*buf_len)) == NULL)
+        (*buf_size) = 32;
+        if ((*buf_ptr = (char *)malloc(*buf_size)) == NULL)
             return CFG_ERR_SYS;
         cp = *buf_ptr;
-        while ((n = fread(cp, 1, (*buf_len)-(cp-(*buf_ptr)), stdin)) > 0) {
+        while ((n = fread(cp, 1, (*buf_size)-(cp-(*buf_ptr)), stdin)) > 0) {
             cp += n;
-            if (((*buf_ptr)+(*buf_len))-cp < (*buf_len)/8) {
-                (*buf_len) *= 2;
+            if (((*buf_ptr)+(*buf_size))-cp < (*buf_size)/8) {
+                (*buf_size) *= 2;
                 n = cp-(*buf_ptr);
-                if ((cp = (char *)realloc(*buf_ptr, *buf_len)) == NULL) {
+                if ((cp = (char *)realloc(*buf_ptr, *buf_size)) == NULL) {
                     free(*buf_ptr);
                     return CFG_ERR_SYS;
                 }
@@ -62,6 +62,7 @@ cfg_rc_t cfg_util_readfile(const char *filename, char **buf_ptr, size_t *buf_len
             }
         }
         *cp = '\0';
+        *buf_used = (cp - *buf_ptr);
     }
     else {
         /* file is given on filesystem */
@@ -80,11 +81,13 @@ cfg_rc_t cfg_util_readfile(const char *filename, char **buf_ptr, size_t *buf_len
                 return CFG_ERR_SYS;
             }
             (*buf_ptr)[n] = '\0';
-            (*buf_len) = n+1;
+            (*buf_size)   = n+1;
+            (*buf_used)   = n;
         }
         else {
-            (*buf_ptr) = strdup("");
-            (*buf_len) = 1;
+            (*buf_ptr)  = strdup("");
+            (*buf_size) = 1;
+            (*buf_used) = 0;
         }
         fclose(fp);
     }
